==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/azurearcdata/kotlin/inputs/LogAnalyticsWorkspaceConfigArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.azurearcdata.kotlin.inputs

import com.pulumi.azurenative.azurearcdata.inputs.LogAnalyticsWorkspaceConfigArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Log analytics workspace id and primary key
 * @property primaryKey Primary key of the workspace
 * @property workspaceId Azure Log Analytics workspace ID
 */
public data class LogAnalyticsWorkspaceConfigArgs(
    public val primaryKey: Output<String>? = null,
    public val workspaceId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.azurearcdata.inputs.LogAnalyticsWorkspaceConfigArgs> {
    override fun toJava(): com.pulumi.azurenative.azurearcdata.inputs.LogAnalyticsWorkspaceConfigArgs =
        com.pulumi.azurenative.azurearcdata.inputs.LogAnalyticsWorkspaceConfigArgs.builder()
            .primaryKey(primaryKey?.applyValue({ args0 -> args0 }))
            .workspaceId(workspaceId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [LogAnalyticsWorkspaceConfigArgs].
 */
@PulumiTagMarker
public class LogAnalyticsWorkspaceConfigArgsBuilder internal constructor() {
    private var primaryKey: Output<String>? = null

    private var workspaceId: Output<String>? = null

    /**
     * @param value Primary key of the workspace
     */
    @JvmName("ndvsqcvwdvchqvky")
    public suspend fun primaryKey(`value`: Output<String>) {
        this.primaryKey = value
    }

    /**
     * @param value Azure Log Analytics workspace ID
     */
    @JvmName("nemepnuqbfgasyha")
    public suspend fun workspaceId(`value`: Output<String>) {
        this.workspaceId = value
    }

    /**
     * @param value Primary key of the workspace
     */
    @JvmName("iwgkkjnqykmhajdy")
    public suspend fun primaryKey(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.primaryKey = mapped
    }

    /**
     * @param value Azure Log Analytics workspace ID
     */
    @JvmName("vvejpejruelfjmoo")
    public suspend fun workspaceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.workspaceId = mapped
    }

    internal fun build(): LogAnalyticsWorkspaceConfigArgs = LogAnalyticsWorkspaceConfigArgs(
        primaryKey = primaryKey,
        workspaceId = workspaceId,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/azurearcdata/kotlin/inputs/LogAnalyticsWorkspaceConfigArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.azurearcdata.kotlin.inputs

import com.pulumi.azurenative.azurearcdata.inputs.LogAnalyticsWorkspaceConfigArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Log analytics workspace id and primary key
 * @property primaryKey Primary key of the workspace
 * @property workspaceId Azure Log Analytics workspace ID
 */
public data class LogAnalyticsWorkspaceConfigArgs(
    public val primaryKey: Output<String>? = null,
    public val workspaceId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.azurearcdata.inputs.LogAnalyticsWorkspaceConfigArgs> {
    override fun toJava(): com.pulumi.azurenative.azurearcdata.inputs.LogAnalyticsWorkspaceConfigArgs =
        com.pulumi.azurenative.azurearcdata.inputs.LogAnalyticsWorkspaceConfigArgs.builder()
            .primaryKey(primaryKey?.applyValue({ args0 -> args0 }))
            .workspaceId(workspaceId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [LogAnalyticsWorkspaceConfigArgs].
 */
@PulumiTagMarker
public class LogAnalyticsWorkspaceConfigArgsBuilder internal constructor() {
    private var primaryKey: Output<String>? = null

    private var workspaceId: Output<String>? = null

    /**
     * @param value Primary key of the workspace
     */
    @JvmName("mwyqlenrmidiwipk")
    public suspend fun primaryKey(`value`: Output<String>) {
        this.primaryKey = value
    }

    /**
     * @param value Azure Log Analytics workspace ID
     */
    @JvmName("nxktgsapopoobovt")
    public suspend fun workspaceId(`value`: Output<String>) {
        this.workspaceId = value
    }

    /**
     * @param value Primary key of the workspace
     */
    @JvmName("ncepajmaslsvhqyc")
    public suspend fun primaryKey(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.primaryKey = mapped
    }

    /**
     * @param value Azure Log Analytics workspace ID
     */
    @JvmName("cgelidxqcrgivxnx")
    public suspend fun workspaceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.workspaceId = mapped
    }

    internal fun build(): LogAnalyticsWorkspaceConfigArgs = LogAnalyticsWorkspaceConfigArgs(
        primaryKey = primaryKey,
        workspaceId = workspaceId,
    )
}
